@@ -1,6 +1,4 @@
-# -*- coding: utf-8 -*-
-from __future__ import unicode_literals
-
+import io
 import logging
 import os
 import sys
@@ -11,7 +9,6 @@ import pytest
 import sh
 
 import dotenv
-from dotenv.compat import PY2, StringIO
 
 
 def test_set_key_no_file(tmp_path):
@@ -280,16 +277,25 @@ def test_load_dotenv_redefine_var_used_in_file_with_override(dotenv_file):
 
 
 @mock.patch.dict(os.environ, {}, clear=True)
-def test_load_dotenv_utf_8():
-    stream = StringIO("a=à")
+def test_load_dotenv_string_io_utf_8():
+    stream = io.StringIO("a=à")
 
     result = dotenv.load_dotenv(stream=stream)
 
     assert result is True
-    if PY2:
-        assert os.environ == {"a": "à".encode(sys.getfilesystemencoding())}
-    else:
-        assert os.environ == {"a": "à"}
+    assert os.environ == {"a": "à"}
+
+
+@mock.patch.dict(os.environ, {}, clear=True)
+def test_load_dotenv_file_stream(dotenv_file):
+    with open(dotenv_file, "w") as f:
+        f.write("a=b")
+
+    with open(dotenv_file, "r") as f:
+        result = dotenv.load_dotenv(stream=f)
+
+    assert result is True
+    assert os.environ == {"a": "b"}
 
 
 def test_load_dotenv_in_current_dir(tmp_path):
@@ -359,11 +365,21 @@ def test_dotenv_values_file(dotenv_file):
         ({}, "a=b\nc=${a}\nd=e\nc=${d}", True, {"a": "b", "c": "e", "d": "e"}),
     ],
 )
-def test_dotenv_values_stream(env, string, interpolate, expected):
+def test_dotenv_values_string_io(env, string, interpolate, expected):
     with mock.patch.dict(os.environ, env, clear=True):
-        stream = StringIO(string)
+        stream = io.StringIO(string)
         stream.seek(0)
 
         result = dotenv.dotenv_values(stream=stream, interpolate=interpolate)
 
         assert result == expected
+
+
+def test_dotenv_values_file_stream(dotenv_file):
+    with open(dotenv_file, "w") as f:
+        f.write("a=b")
+
+    with open(dotenv_file, "r") as f:
+        result = dotenv.dotenv_values(stream=f)
+
+    assert result == {"a": "b"}
